# Backend.AI 클라우드 통합 서비스 이용약관 (한국어)

## 제1장 일반 조건

### 제1조 (목적)

본 서비스 약관(이하 “본 약관” 또는 “약관”)은 래블업 주식회사(이하 “회사”)가 제공하는 Backend.AI 클라우드 서비스(이하 “서비스”)를 이용함에 있어 회사와 이용회원(이하 “회원”) 간의 권리와 의무, 책임사항 및 기타 필요한 사항을 규정함을 목적으로 합니다.

### 제2조 (정의)

본 약관에서 사용하는 용어의 정의는 다음과 같고, 본 조에서 정하는 것을 제외하고는 관계 법령, 서비스 운영정책 및 기타 일반적인 상관례에 의합니다.

1. "회원"이란 본 약관에 동의하고 서비스의 이용을 위해 회사와 이용계약을 체결한 사용자를 의미합니다.

2. “사이트”란 회사가 운영하는 웹사이트를 말하며, 통합된 하나의 아이디 및 비밀번호를 이용하여 서비스를 제공받을 수 있는 아래의 사이트를 의미합니다.

   - 사이트 현황 (2019년 8월 16일 기준)

     - 회사 대표 홈페이지 : https://lablup.com,
     - Backend.AI 클라우드 : https://www.backend.ai

3. “계정"이라 함은 회원의 식별과 서비스 이용을 위하여 회원이 선정하고 회사가 부여하는 문자, 숫자 또는 특수 문자의 조합을 의미합니다.

4. "비밀번호"라 함은 회원이 부여받은 계정과 일치되는 회원임을 확인하고 회원의 정보 및 권익보호를 위해 회원 자신이 선정하여 비밀로 관리하는 문자, 숫자 또는 특수 문자의 조합을 의미합니다.

5. "계정정보"라 함은 회원의 계정, 비밀번호, 성명 등 회원이 회사에 제공한 일반정보 및 서비스 이용정보 등 생성 정보를 의미합니다.

6. “크레딧”이라 함은 회사가 제공하는 서비스를 이용하기 위한 단위로서 1크레딧은 현금 1원과 동일한 가치를 갖습니다.

7. “클라우드 서비스”라 함은 이용자 개인 기기가 아닌 인터넷으로 연결된 외부 서버(클라우드 서버)에 설치된 하드웨어 및 소프트웨어를 통해 이용자에게 정보통신기술 자원을 제공하는 서비스를 의미합니다.

### 제3조 (약관의 명시와 개정)

1. 회사는 본 약관의 내용을 회사의 상호, 영업소 소재지, 대표자의 성명, 사업자 등록번호, 연락처 등과 함께 회원이 확인할 수 있도록 회사 홈페이지(https://lablup.com, 이하 같음)및 서비스 페이지(https://www.backend.ai, 이하 같음)에 게시하거나 연결화면을 제공하는 방법으로 회원에게 공지합니다.
2. 회사는 약관의 규제에 관한 법률 등 관련 법령에 위배하지 않는 범위에서 이 약관을 수시로 개정할 수 있습니다.
3. 회사가 약관을 개정하는 경우에는 개정내용, 개정사유, 적용일자 등을 명시하여 그 적용일자로부터 최소한 7일 이전(회원에게 불리하거나 중대한 사항의 변경은 30일 이전)부터 그 적용일자 전일까지 제4조에서 정하는 바에 따라 회원에게 통지합니다.
4. 회사가 약관을 개정하는 경우에는 원칙적으로 개정약관 통지 후 개정약관의 적용에 대한 회원의 동의 여부를 확인합니다. 다만 개정약관 통지 시 회원이 동의 또는 거부의 의사표시를 하지 않으면 승낙한 것으로 간주하겠다는 내용을 함께 통지할 수 있고, 이 경우 회원이 개정약관 시행일까지 동의 또는 거부의 의사표시를 하지 않거나 탈퇴하지 않으면 그 회원은 개정약관에서 정한 모든 내용에 대하여 동의한 것으로 간주됩니다.
5. 회사는 개정약관의 적용에 동의하지 않는 회원에 대하여 개정약관의 내용을 적용할 수 없습니다. 이 경우 회사 및 회원은 서비스 이용계약을 해지할 수 있습니다.
6. 본 조에 의하여 개정된 약관은 원칙적으로 그 효력 발생일(적용일자)로부터 장래를 향하여 유효합니다.

### 제4조 (회원에 대한 통지)

1. 회사가 회원에게 통지해야 하는 경우, 약관에서 별도로 명시하지 아니하는 한 회사는 이용신청 시 회원이 등록한 이메일 주소를 이용하여 통지합니다. 다만 이메일 주소를 이용한 통지가 곤란한 사정이 있는 경우 휴대폰 문자 메시지, 서면 통보 등 기타 적절한 수단을 이용하여 통지할 수 있습니다.
2. 회원 전체에 통지해야 하는 경우, 회사는 제1항에서 정한 방식 외에 회사 홈페이지 또는 서비스 페이지에 7일 이상 공지함으로써 통지를 대신할 수 있습니다. 다만 회원의 권리 및 의무와 관련하여 회원에게 불리한 변경사항을 통지하는 경우에는 본 조항이 적용되지 아니합니다.
3. 회원은 회사의 통지를 적절하게 수신할 수 있도록 자신의 연락처에 관한 정보(이메일 주소, 휴대전화 번호, 유선 전화번호 등)를 항상 최신 상태로 유지할 의무가 있습니다. 회원의 연락처 정보가 업데이트 되어 있지 않아 회원에게 발생하는 일체의 불이익에 대하여 회사는 어떠한 책임도 부담하지 않습니다.

## 제2장 서비스 이용

### 제5조 (회원가입 및 서비스 이용계약)

1. 회원이 되고자 하는 자(이하 “가입신청자”)가 약관의 내용에 동의하고 회사가 정한 양식에 따라 회원정보를 기입하여 회원가입 신청(이하 “이용신청”)을 한 후 회사가 이에 대하여 승낙함으로써 서비스 이용계약(이하 “이용계약”)이 성립합니다.
2. 가입신청자는 이용신청 당시 회사의 약관에 동의함을 선택하거나 기타 이에 준하는 방법으로써 약관에 대하여 동의한다는 의사를 표시합니다.
3. 회사는 가입신청자에게 실명확인 및 본인인증, 기타 필요한 정보를 요구할 수 있으며, 그 절차와 방식은 관련 법령에 따릅니다.
4. 회사는 서비스를 제공함에 있어서 사용범위, 이용 가능 시간, 이용 가능 횟수, 이용 요금 등 필요한 사항을 지정할 수 있으며, 회원은 그와 같이 정해진 제공 조건에 따라서만 서비스를 이용할 수 있습니다.
5. 가입신청자는 이용신청 시 회사가 요구하는 정보 항목에 대하여 진실된 정보를 기재하여야 합니다. 실명 또는 정보를 허위로 기재하거나 타인의 명의를 도용한 경우 이 약관에 의한 회원의 권리를 주장할 수 없고, 회사는 환급 없이 해당 회원과의 이용계약을 취소하거나 해지할 수 있습니다.
6. 가입신청자가 이용신청 시 제공한 개인정보는 관련 법령 및 회사의 개인정보 보호정책에 의하여 보호됩니다.

### 제6조 (이용신청의 승낙과 제한)

1. 가입신청자가 제5조에서 정하는 바에 따라 정당하게 이용신청을 한 경우 특별한 사유가 없는 한 회사는 그 이용신청을 승낙합니다.
2. 회사는 다음 각 호의 어느 하나에 해당하는 이용신청에 대해서는 승낙을 하지 않을 수 있고, 이미 체결된 이용계약을 해지할 수 있습니다.
   1. 실명을 사용하지 않았거나 타인의 명의를 이용하여 이용신청을 하는 경우
   2. 최근 3개월 내 자신의 책임 있는 사유에 의한 이용제한 기록이 있는 자가 이용신청을 하는 경우
   3. 법령에서 금지하는 위법행위를 할 목적으로 이용신청을 하는 경우
   4. 본 서비스와 경쟁관계에 있는 자가 회사의 이익을 저해하려는 목적으로 이용신청을 하는 경우
   5. 이전에 회원의 자격을 상실한 적이 있는 자로서 회사의 회원 재가입 승낙을 얻지 못한 경우
   6. 그 밖에 위 각 호에 준하는 사유로서 회사가 회원에게 서비스를 제공하는 것이 부적합 또는 곤란하다고 판단되는 경우
3. 회사는 다음 각 호의 어느 하나에 해당하는 경우에는 그 사유가 해소될 때까지 이용신청에 대한 승낙을 유보할 수 있습니다.
   1. 서비스 관련 제반 용량의 부족 등 회사의 설비에 여유가 없는 경우
   2. 기술상 장애 사유가 있는 경우
   3. 그 밖에 위 각 호에 준하는 사유로 이용신청의 승낙이 부적합 또는 곤란하다고 판단되는 경우
4. 회사가 이용신청을 승낙하지 않거나 승낙을 유보하는 경우 회사는 제4조에 정하는 바에 따라 가입신청자에게 이를 통지합니다.
5. 회원의 이용신청에 대하여 회사가 승낙한 경우 회원이 본 약관 및 관련 법령을 위반하지 않은 이상 회원과 회사 간에 유효하게 이용계약이 체결된 것으로 봅니다.

### 제7조 (회원 계정(ID) 및 비밀번호)

1. 회사는 회원에 대하여 계정(ID)(이하 “계정”)을 부여하되, 그 계정은 해당 회원이 사용하는 이메일 주소의 형태로 합니다.
2. 회사는 계정정보를 통하여 당해 회원의 서비스 이용가능 여부 등을 판단하는 등 제반 회원 관리업무를 수행할 권한이 있으며, 다음 각 호의 어느 하나에 해당하는 경우에는 회원의 계정 및 비밀번호의 변경을 요구하거나 변경할 수 있습니다.
   1. 회원의 계정이 타인에게 혐오감을 주거나 미풍양속을 저해하는 것으로 판단되는 경우
   2. 회사의 보안상 필요 또는 서비스의 원활한 제공 등의 목적으로 변경할 필요성이 있는 경우
   3. 그 밖에 위 각 호에 준하는 사유로서 회사가 필요하다고 인정하는 경우
3. 회원은 자신이 생성한 계정을 선량한 관리자의 주의 의무로 관리하고 해당 회원 자신만이 이를 사용하여야 합니다. 회원이 본인의 계정정보를 소홀하게 관리하거나 제3자에게 사용을 승낙함으로써 발생하는 손해에 대하여는 그 회원에게 책임이 있습니다.
4. 비밀번호의 관리책임은 회원에게 있으며, 회원이 보안상의 이유 등으로 비밀번호의 변경을 원하는 경우에는 언제든지 변경할 수 있습니다.
5. 회원은 계정정보가 도용되거나 제3자가 이를 사용하고 있음을 인지한 경우 이를 즉시 회사에 통지하고 회사의 안내에 따라야 합니다. 회원이 이를 인지하고서도 회사에 통지하지 않거나, 통지한 경우라도 회사의 안내에 따르지 않아 발생한 피해에 대하여 회사는 어떠한 책임도 부담하지 않습니다.
6. 회원이 자신의 계정을 관리하지 않아 발생하게 된 제3자의 손해는 그 회원이 배상하여야 하며, 회사는 이에 대하여 어떠한 책임도 부담하지 않습니다.

### 제8조 (회원 정보의 제공 및 변경)

1. 회원은 본 약관에 의하여 회사에 정보를 제공하여야 하는 경우에는 진실된 정보를 제공하여야 하며, 허위정보 제공으로 인해 발생한 불이익에 대해서는 보호받지 못합니다.
2. 회원은 회사 홈페이지 또는 서비스 페이지를 통하여 언제든지 자신의 개인정보를 열람하고 수정할 수 있습니다. 다만 서비스 관리를 위해 필요한 실명, 계정 등은 수정이 불가능합니다. 따라서 부득이한 사유로 인하여 계정을 변경하고자 하는 경우에는 해당 계정을 해지하고 재가입해야 합니다. 회원탈퇴 후 해당 계정은 영구적으로 사용이 중지되므로 해당 계정으로는 재가입이 불가능합니다.
3. 회원은 회사에 제공한 정보가 변경되었을 경우 회사 홈페이지 또는 서비스 페이지를 통해 직접 수정을 하여야 하며, 직접 수정이 불가능한 경우에는 회사에 대하여 그 변경사항을 알려야 합니다.
4. 회원이 회원정보의 변경사항을 직접 수정하지 아니하거나 이를 회사에 알리지 아니하여 발생하는 문제의 책임은 회원에게 있으며, 이와 관련하여 발생한 회원의 불이익에 대하여 회사는 책임을 지지 않습니다.

### 제9조 (통합 회원제)

1. 회원은 통합된 하나의 계정을 통해 본 약관 제2조 제2항에서 명시한 사이트를 모두 이용할 수 있습니다.
2. 회사는 일부 사이트의 특정 서비스를 제공하기 위하여 회원에게 별도 또는 추가적인 가입 절차를 요구할 수 있으며, 이러한 특정 서비스를 이용할 경우 해당 사이트 또는 서비스에 대한 이용약관, 규정 등(별도로 존재하는 경우)이 본 약관보다 우선하여 적용됩니다.
3. 회사는 회원이 사이트 및 서비스를 쉽게 이용할 수 있도록 회원의 계정을 포함한 개인정보를 관리하거나 사이트 또는 서비스를 개선, 변경할 수 있습니다.
4. 회원의 회원가입 신청 및 이에 대한 회사의 승낙 이후 회사는 본 약관 제2조 제2항에 사이트를 추가할 수 있으며, 이 경우 해당 사이트의 이용에 관하여 별도 약관으로 명시하지 않는 한 본 약관이 적용됩니다.

### 제10조 (개인정보의 보호 및 관리)

1. 회사는 관련 법령이 정하는 바에 따라 계정정보 등을 포함한 회원의 개인정보를 보호하기 위해 노력합니다. 회원의 개인정보의 보호 및 사용에 관하여는 관련 법령 및 회사가 별도로 고지하는 개인정보처리방침이 적용됩니다.
2. 회사는 회원이 안전하게 서비스를 이용할 수 있도록 개인정보, 신용정보의 보호를 위한 보안시스템을 갖추어야 하며, 개인정보처리방침을 공시하고 이를 준수합니다. 회사는 관련 법령, 본 약관 및 개인정보처리방침에서 정한 경우를 제외하고는 회원의 개인정보가 제3자에게 공개 또는 제공되지 않도록 합니다.
3. 회사는 회원의 귀책사유로 인하여 노출된 회원의 계정정보를 포함한 모든 개인정보, 비밀정보에 대해서 일체의 책임을 지지 않습니다.

### 제11조 (회원에 대한 서비스)

회원은 회사가 제공하는 시스템을 통하여 다음과 같은 서비스를 제공받을 수 있습니다.

1. 회원이 별도의 하드웨어 및 소프트웨어 구매 없이 네트워크 상에서 프로그래밍 및 머신러닝 모델 개발과 실행 등을 위한 작업을 수행할 수 있도록 하는 클라우드 서비스
2. 회원이 별도의 하드웨어 및 소프트웨어 구매 없이 네트워크 상에서 데이터를 보관, 저장 및 관리할 수 있도록 하는 클라우드 서비스
3. 기타 회사가 추가 개발하거나 다른 회사와의 제휴 등을 통해 회원에게 제공하는 일체의 서비스
4. 제1호 내지 제3호의 서비스와 관련한 기술지원 등 제반 서비스

### 제12조 (서비스의 변경 및 내용 수정)

1. 회사는 운영상, 기술상의 필요에 따라 서비스 내용을 수정하거나 변경할 수 있으며, 이 경우 변경사항을 회원에게 통지합니다.
2. 회사가 서비스의 변경사항에 관하여 적절한 통지를 하였음에도 불구하고 회원이 이를 성실하게 수령하지 아니하여 발생한 일체의 손해에 대하여 회사는 책임을 지지 않습니다.

### 제13조 (지식재산권)

1. 서비스에 대한 지식재산권 기타 일체의 권리는 회사에게 있습니다.
2. 회원이 서비스 이용 과정에서 생산한 개발결과물 기타 산출물(이하 “산출물”)에 대한 지식재산권 기타 일체의 권리는 회원에게 귀속합니다. 회원은 본 약관을 통해 회사가 서비스 제공과 관련하여 산출물을 보관, 저장, 관리 등 처리하는 것에 동의하며, 회사에 그에 필요한 일체의 권리를 부여합니다.
3. 회원은 회사가 허용하는 목적 및 방법의 범위 내에서 서비스를 이용하여야 하며, 그에 위반하여 제3자의 지식재산권 기타 권리를 침해하여서는 아니됩니다. 이 경우, 제3자의 권리 침해에 관한 책임은 전적으로 회원에게 있으며, 회사는 이와 관련하여 어떠한 책임도 부담하지 않습니다.

### 제14조 (서비스의 제공 및 중단 등)

1. 회사는 회원의 이용신청을 회사가 승낙한 때부터 해당 회원에 대한 서비스의 제공을 개시합니다. 다만 필요한 경우 일부 서비스는 특정 시점부터 개시할 수 있고, 이 경우 회사는 사전 또는 사후에 이를 회원에게 통지합니다.
2. 회사는 필요한 경우 특정 회원에 대하여만 특정 서비스를 제공할 수 있고, 서비스를 일정 범위로 분할하여 각 범위에 따라 이용 가능 시간을 별도로 정할 수 있습니다. 이 경우 회사는 사전 또는 사후에 이를 회사 홈페이지 또는 서비스 페이지를 통해 공지하거나 해당 회원에게 개별적으로 통지합니다.
3. 회사는 연중무휴, 하루 24시간, 주 7일의 서비스를 제공함을 원칙으로 합니다.
4. 제3항에도 불구하고 다음 각 호의 어느 하나에 해당하는 경우에는 일정한 시간 동안 서비스가 제공되지 아니할 수 있으며, 해당 시간 동안 회사는 서비스를 제공할 의무가 없습니다.
   1. 컴퓨터 등 정보통신설비의 보수점검, 교체, 정기점검 또는 서비스의 수정을 위하여 필요한 경우
   2. 해킹 등의 전자적 침해사고, 통신 사고, 회원들의 비정상적인 서비스 이용행태, 예상할 수 없는 서비스의 불안정성에 대응하기 위하여 필요한 경우
   3. 관련 법령에서 특정 시간 또는 방법으로 서비스를 제공하는 것을 금지하는 경우
   4. 천재지변, 국가비상사태, 정전, 서비스 설비의 장애 또는 서비스 이용의 폭주 등으로 정상적인 서비스 제공이 불가능할 경우
   5. 분할, 합병, 영업양도, 영업의 폐지, 당해 서비스의 수익 악화 등 회사의 경영상 필요에 의한 경우
5. 회사는 제4항 각 호의 경우 가능한 한 사전에 그 사실을 회사 홈페이지 또는 서비스 페이지 등을 통해 회원에게 고지하기 위하여 노력하며, 회사가 적절한 방법으로 회원에게 이를 고지하였음에도 불구하고 회원이 그 내용을 인지하지 못하여 발생한 일체의 손해에 대하여 회사는 책임을 부담하지 않습니다. 사전에 고지하는 것이 불가능 또는 심히 곤란한 부득이한 사정(긴급한 시스템 점검증설교체, 시스템 관리자의 고의, 과실 없는 디스크 장애시스템 다운, 제3자인 PC통신 회사, 기간통신사업자 등의 사정으로 인한 서비스 제공의 불가 등 회사가 통제할 수 없는 사정)이 있는 경우에는 그 사정이 종료된 후 즉시 사후적으로 이를 고지를 할 수 있습니다.
6. 제4항 각 호의 사유에 의한 서비스 중지로 인하여 회원의 데이터가 저장되지 못하였거나 그 데이터에 손실이 발생한 경우, 회사에 고의 또는 중과실이 있지 아니하는 한 회사는 이에 대한 책임을 부담하지 않습니다.

### 제15조 (회사에 의한 서비스 이용의 정지 또는 종료)

1. 회사는 회원이 본 약관을 위반한 경우 또는 다음 각 호의 어느 하나에 해당하는 경우 회원에 대한 사전통지 없이 이용계약을 정지할 수 있습니다.
   1. 회원이 요금을 납부 월까지 납입하지 않은 경우
   2. 안정된 서비스 운용을 저해할 수 있는 다량의 정보 전송, 광고성 정보를 전송 또는 매개하는 행위를 하거나 이러한 행위가 발생하는 경우
   3. 회원 서버에서 실행중인 프로그램으로 인하여 다른 회원 시스템의 운영에 피해가 발생하거나, 회사의 서비스 운영에 지장 또는 장애가 발생한 경우 또는 그러한 피해 내지 지장, 장애가 발생할 위험이 있는 경우
   4. 회원이 서비스를 이용하여 운영중인 시스템과 관련하여 비정상 과다 트래픽이 발생하여 네트워크에 영향을 끼치는 경우
   5. 회원이 보안 업데이트를 서버에 적절하게 설치하지 않음으로 인하여 회사의 서비스 운영에 위험이 발생할 것으로 예상되는 경우
   6. 회원이 이용중인 서버가 바이러스에 감염 또는 해킹되었거나 그러한 것으로 의심되는 경우
   7. 회원이 회사가 서비스 이용을 위하여 정한 조건 또는 서비스 이용과 관련하여 고지한 제약 및 제한 사항을 회피하는 방식(예를 들면, 무료로 서비스를 이용하거나 특가 혜택을 받기 위하여 복수의 계정을 생성하는 등)으로 본 서비스에 접근하거나 이를 사용하는 경우 비실명 회원가입, 주민등록번호의 도용 등 회원이 제공한 정보가 허위임이 판명된 경우
   8. 회원이 현행법 위반 또는 고의 또는 중대한 과실로 회사에 손해를 입힌 경우
   9. 국익 또는 사회적 공익을 저해할 목적으로 서비스 이용을 계획 또는 실행할 경우
   10. 회원이 회사의 서비스를 가상화폐 채굴 용도로 이용하는 경우
   11. 타인의 서비스 계정 및 비밀번호를 도용한 경우
   12. 제22조에서 정한 회원의 의무를 위반하고 있으며, 회사의 해소 요구에 대하여 상당한 기간 동안 적절한 조치를 취하지 않고 있는 경우
   13. ‘개인정보 유효 기간제’에 따라 1년간 서비스를 이용하지 않은 회원의 개인정보 보호를 위하여 해당 정보의 삭제가 필요한 경우
   14. 타인의 명예를 손상시키거나 타인에게 서비스 이용과 관련한 심대한 불이익을 주는 경우
   15. 같은 회원이 복수의 계정으로 중복 등록을 한 경우
   16. 서비스에 위해를 가하는 등 서비스의 건전한 이용을 저해하는 경우
   17. 기타 관련 법령이나 회사가 정한 이용조건에 위배되는 경우
2. 제1항 각 호에서 정한 사유가 2회 이상 반복적으로 발생하거나 그 사유가 발생하고 회사가 해당 회원에게 시정을 요구하였음에도 불구하고 1개월 이내에 시정조치가 이루어지지 않는 경우 회사는 회원에 대한 사전통지나 추가 협의 없이 이용계약을 해지할 수 있습니다.
3. 제1항 각 호에서 정한 사유로 인하여 회사가 회원의 서비스 이용을 정지하는 경우, 회사는 정지 사유, 정지 기간 및 공식적인 이의제기 수단을 해당 회원에게 통지합니다. 이때 서비스 이용 정지의 원인이 된 사유가 제거되거나 더 이상 유효하지 않게 되는 경우 회사는 지체없이 회원의 서비스 이용 권리를 회복시킵니다.
4. 본 조에서 정하는 일체의 사유로 인하여 이용계약이 정지 또는 해지된 경우, 회사는 그 정지된 기간 동안 또는 그 해지되는 시점 전까지 발생한 이용요금을 해당 회원에게 청구할 수 있습니다.
5. 본 조에 의하여 이용계약이 해지되는 경우 회원에게 제공되는 서비스는 모두 중단되며, 그 회원의 활동과 관련하여 누적된 사항은 모두 비공개 처리됩니다.

### 제16조 (회원에 의한 서비스의 중지 또는 해지)

1. 회원이 이용계약을 중지하거나 해지하기를 원하는 경우, 회사 홈페이지 또는 서비스 페이지에 게시한 절차와 방법을 통하여 회사에게 이를 통지하여야 합니다. 회사는 정상적인 조건 하에서 회원이 요청한 날짜에 중지 일정에 따라 서비스를 중지하거나 이용계약을 종료합니다. 다만 회원이 계약 해지를 요청한 날 납부해야 할 이용요금이 남아 있다면, 해당 회원이 그 이용요금을 전액 납부한 후에야 해지 절차를 진행할 수 있습니다.
2. 회원은 서비스 이용 기간 동안 사용한 서버에 저장된 일체의 데이터를 이용계약의 해지 이전에 직접 백업해야 합니다. 회사는 이용계약의 해지와 동시에 회원의 모든 서버 및 자원을 삭제하고, 삭제된 서버와 자원은 어떠한 이유로든 복구되지 않습니다.
3. 회원은 회사 홈페이지 또는 서비스 페이지를 통하여 회원에서 탈퇴할 수 있습니다. 회원이 탈퇴를 신청한 경우 회사는 회원 본인의 신청인지 여부를 확인할 수 있으며, 회사는 확인 완료 후에 회원의 신청에 따른 조치를 취합니다.

### 제17조 (정보 제공 및 광고의 게재)

1. 회사는 회원의 편의를 위하여 회원이 서비스 이용 중 필요하다고 인정되는 다양한 정보를 이메일이나 우편, 문자 메시지, 어플리케이션 알림 등의 방법으로 회원에게 제공할 수 있습니다. 그러나 회원이 이를 수신하기를 원하지 않는 경우에는 회사 홈페이지 또는 서비스 페이지의 관련 페이지에서 이에 대한 수신거부를 설정할 수 있습니다.
2. 회사는 동의한 회원에 한하여 다음 각 호의 정보를 제공하며, 회원은 회사 홈페이지 또는 서비스 페이지의 관련 페이지에서 언제든지 동의를 철회할 수 있습니다.
   1. 뉴스레터
   2. 기술정보
   3. 신규 서비스 관련 알림
3. 회사 홈페이지 및 서비스 페이지 등에는 배너와 링크(Link) 등 다양한 형태의 광고가 포함될 수 있으며, 이는 제3자가 제공하는 페이지와 연결될 수 있습니다.
4. 제4항에 따라 제3자가 제공하는 페이지로 연결될 경우 해당 페이지는 회사의 서비스 영역이 아니므로 회사가 그 페이지의 신뢰성, 안정성 등을 보장하지 않으며, 이와 관련하여 회원에게 손해가 발생한 경우에도 회사는 이에 대한 책임을 지지 않습니다.

## 제3장 이용요금 및 관리

### 제18조 (서비스 이용요금)

1. 회사는 회원이 이용한 서비스와 관련하여 일정 금액의 이용요금(이하 “이용요금”)의 지급을 청구할 수 있습니다.
2. 이용요금은 회원이 이용하는 서비스의 유형, 서비스 이용시간 및 서비스를 통해 처리한 데이터의 분량 기타 다양한 요소에 기초하여 산정되며, 회원은 이용요금의 지급에 관하여 다음 각 호에서 정하는 방식 가운데 하나 이상의 방식을 선택할 수 있습니다. 다만 구체적인 이용요금 산정 방식, 크레딧의 부여 및 사용 방법 등 관련 제반 사항은 서비스 페이지 또는 어플리케이션 내 게시판 등을 통해 게시되거나 이메일 기타 별도의 절차를 통해 통지됩니다.
   1. 기간제 정액요금 선불 납부 방식
   2. 크레딧 충전을 위한 선불 납부 방식
   3. 월간 사용량에 따른 차월 과금 방식
3. 회사는 이용요금에 일정 비율에 따른 할인을 적용할 수 있고, 그와 관련된 구체적인 사항은 서비스 페이지 또는 어플리케이션 내 게시판 등을 통해 게시되거나 이메일 기타 별도의 절차를 통해 통지됩니다.
4. 회사는 필요한 경우(예: 회원이 서비스와 관련하여 대량의 자원을 사용할 것이 예상되는 경우 등)에는 해당 회원과 별도 합의하여 이용요금에 관한 사항을 본 조와 달리 정할 수 있습니다.
5. 회사는 회원에게 사전통지를 함으로써 이용요금에 관한 기존의 사항을 변경할 수 있습니다.

### 제19조 (이용요금 청구 및 지급)

1. 회사는 회원이 선불 납부 방식으로 이용요금을 지급하는 경우를 제외하고는(이하 본조에서 같음) 이용요금 발생 해당 월의 다음 달에 회원에게 청구서를 발행하며, 회원은 회사가 사전에 명시한 지급기일 당일 또는 그 이전에 청구된 금액을 이용요금으로 지급하여야 합니다.
2. 이용요금의 지급은 신용카드, 계좌이체 등 회사가 지정하는 지급 수단 중 어느 하나를 통하여 이루어져야 합니다.
3. 회사는 회원이 이용요금 지급기일 최소 5일 전에 이용요금 청구서를 받을 수 있도록 사전에 이를 발송합니다.
4. 회원이 지급기일 내에 회사에 이용요금을 지급하지 않는 경우 회사는 이메일 등 적절한 수단을 통해 미납 이용요금에 대한 통지를 할 수 있으며, 미납 이용요금에 대하여는 가산금(매월 미납 금액의 2%)이 추가되어 재청구됩니다.
5. 회원이 다음 달 말일까지 이용요금을 납부하지 않는 경우, 회사는 약관에 명시하거나 회사 홈페이지 또는 서비스 페이지에 게시된 절차 및 방법에 따라 해당 회원과의 이용계약을 해지할 수 있고, 해당 회원은 그 즉시 이미 발생한 이용요금의 전액을 회사에 납부하여야 합니다.

### 제20조 (이용요금 납부의 책임)

1. 회원은 본 약관 및 회사 홈페이지 또는 서비스 페이지에 공지된 바에 따라 회사에 이용요금을 지급할 의무가 있습니다. 단, 회원이 이용요금 지급 책임자를 별도로 지정한 경우 회원과 그 지급 책임자는 이용요금 지급에 대하여 연대책임을 부담합니다. 이 경우 회원은 지급 책임자의 책임 확인서를 회사에 제공하여야 합니다.
2. 후불제 방식으로 이용요금을 납부하는 회원이 회사로부터 청구된 이용요금에 동의하지 않는 경우, 회원은 서면 또는 이메일을 통하여 회사에 이의를 제기할 수 있습니다. 이 경우 회사는 이의제기를 접수한 이후 7일 이내에 이를 검토하여 회원에게 그 결과를 알려야 하고, 그 기간을 준수하지 못하는 경우 회사는 회원에게 그 지연 사유를 통지합니다.

## 제4장 계약당사자의 의무

### 제21조 (회사의 의무)

1. 회사는 관련 법령과 본 약관이 정하는 권리의 행사와 의무의 이행을 신의에 좇아 성실하게 하고, 안정적이고 지속적인 방식으로 회원이 요청하는 서비스를 제공하기 위해 노력합니다.
2. 회사는 서비스의 정상 운영에 지장을 주는 장애가 발생한 경우 천재지변, 비상사태, 해결이 곤란한 기술적 결함 등 부득이한 사유가 없는 한 지체없이 이를 수리 또는 복구하도록 최선의 노력을 다합니다. 다만 협력사의 설비에 장애가 생기거나 협력사의 고의 또는 과실로 인하여 데이터 등이 멸실, 훼손, 손상(이하 “멸실 등”)된 때에는 회사에 고의 또는 중과실이 없는 한 회사는 해당 데이터 등의 멸실 등으로부터 면책됩니다.
3. 회사는 회원이 제기한 의견이나 불만이 정당하다고 인정되는 경우 회사가 정한 절차에 따라 공정하게 즉시 또는 기간 내에 처리합니다. 다만 신속한 처리가 곤란한 경우에는 회원에게 그 사유와 처리 일정을 통보합니다.
4. 회사는 이용약관에 벗어난 목적으로 서비스와 관련한 회원의 정보에 접근하거나 데이터를 처리하지 않습니다. 다만 장애 처리, 회원의 정보 보호 등 원활한 서비스 제공을 위하여 접근이 필요한 경우 이에 접근하여 내용을 파악할 수 있습니다.

### 제22조 (회원의 의무)

1. 회원은 다음 각 호에서 정하는 행위를 하여서는 안 됩니다.
   1. 비정상적인 시스템 접근
      1. 악성코드, 바이러스 등의 프로그램을 고의 또는 과실로 설치, 유포하는 행위
      2. 리버스엔지니어링, 디컴파일, 디스어셈블 및 기타 일체의 가공행위를 통하여 서비스를 복제, 분해 또는 모방 기타 변형하는 행위
   2. 비정상적인 서비스 이용
      1. 실제 정보와 일치하지 않는 정보 또는 타인의 정보로 회원가입을 하는 행위
      2. 다수의 계정으로 활동을 하는 행위
      3. 계정 내 불리한 정보를 삭제하기 위해 의도적으로 계정을 탈퇴/재가입하는 행위
   3. 허위 또는 과장된 정보 입력
      1. 허위 또는 과장된 정보를 입력하여 타인의 서비스 이용을 방해하거나 방해할 위험을 야기하는 행위
   4. 공공질서 위반
      1. 성별, 정치, 종교, 장애, 연령, 사회적 신분, 인종, 지역, 직업 등을 차별하거나 이에 대한 편견을 조장하는 행위
      2. 회사, 다른 회원 또는 제3자를 차별 또는 비방하거나 명예를 훼손하는 행위
      3. 회사, 다른 회원 또는 제3자에 대하여 욕설, 폭언, 협박 등을 하는 행위
      4. 과도한 신체 노출이나 음란한 행위를 묘사하거나, 성매매 관련 정보를 공유하거나, 타인에게 성적 수치심 또는 불쾌감을 유발할 수 있는 내용을 게시하는 등 미풍양속에 반하는 정보를 회사 홈페이지 또는 서비스 페이지에 등록하는 행위
      5. 혐오스러운 사진 또는 내용을 게시하거나, 욕설, 비속어, 은어를 사용하는 등 사회 통념에 반하는 비정상적인 활동을 하는 행위
   5. 타인의 권리 침해
      1. 회사, 다른 회원 또는 제3자의 특허권, 상표권, 저작권 등 지적재산권을 침해하는 행위 또는 침해할 우려가 있는 행위
      2. 타인의 개인정보를 침해하는 행위
      3. 타 웹 해킹 프로그램, 매크로 프로그램, 보이스 피싱을 위한 미러링 사이트 등 타인의 권리를 침해하거나 침해할 우려가 있는 모든 행위
   6. 계정거래, 양도, 대리, 교환 등
      1. 계정 및 계정 내 컨텐츠를 타인에게 판매, 양도, 대여하거나, 타인에게 그 이용을 허락 또는 이를 시도하는 행위 및 이를 알선하는 행위
   7. 명의 사칭, 도용 등
      1. 회원이 다른 회원, 제3자 또는 회사의 직원을 사칭하는 행위
   8. 기타
      1. 회사가 게시한 정보를 무단으로 변경하는 행위
      2. 회사의 동의 없이 영리, 영업, 광고, 정치활동 등을 목적으로 서비스를 사용하는 행위
      3. 자기 또는 타인에게 재산상의 이익을 주거나 타인에게 손해를 가할 목적으로 허위의 정보를 유통시키는 행위
      4. 기타 관련 법령에서 금지하거나 선량한 풍속 기타 사회통념상 허용되지 아니하거나 원활한 서비스 제공에 악영향을 끼치는 일체의 행위
2. 회사는 회사 홈페이지 또는 서비스 페이지에 회원의 불법행위 등을 회사에 알리거나 신고할 수 있는 메뉴를 설치하여 운영할 수 있습니다.
3. 서비스를 이용하여 제3자의 개인정보를 처리, 관리 또는 이용하거나 이에 접속하는 경우, 회원은 관련 법령을 준수하여 해당 개인정보를 관리하고 보호하여야 하며, 회사는 이와 같은 행위로 발생하는 결과, 손실 또는 손해(제3자의 정보 유출 등을 포함하되 이에 한정되지 않음)에 대하여 책임을 지지 않습니다.
4. 회원은 서비스를 통해 회원이 운영하는 서버, 소프트웨어 프로그램 등에 대한 권리를 모두 보유 또는 획득하여야 하며, 이와 관련하여 발생하는 저작권 문제 등에 대하여 전적으로 책임을 져야 합니다.
5. 회원이 서비스를 통해 불법 소프트웨어 또는 스팸 메일을 배포 또는 발송하여 다른 회원 또는 제3자에게 피해를 준 경우, 회사는 이에 대한 책임이 없으며 해당 회원은 회사를 면책시키고 의무, 손실, 손해배상, 회사를 상대로 제기되는 소송 등으로부터 회사가 피해를 입지 않도록 모든 노력을 다하여야 합니다.
6. 회원은 본 약관의 규정, 이용안내 및 서비스와 관련하여 공지한 주의사항, 회사가 통지하는 사항 등을 확인하고 이를 준수할 의무가 있습니다.
7. 회원은 서비스를 이용하면서 취급하는 데이터를 백업하고 저장할 의무가 있으며, 데이터 관리 소홀로 인한 손실이 발생한 경우 이에 대한 책임을 져야 합니다.
8. 회원은 본 약관에 의한 서비스의 이용권한, 회사와 회원 사이의 서비스 계약 등 기타 이용계약 상의 권리, 지위 등을 타인에게 양도 및 증여할 수 없으며, 이를 담보로 제공할 수 없습니다.
9. 미성년자가 서비스 이용을 위하여 결제하려는 경우 법정대리인이 해당 계약에 대하여 동의를 하여야 정상적인 결제가 진행될 수 있고, 회사는 이를 확인하기 위하여 관련 자료의 제출 등을 요구할 수 있습니다. 그밖에 미성년자의 거래에 관한 사항은 관련 법령이 정한 바에 의합니다.

### 제23조 (회원의 의무위반에 대한 제재)

1. 회원이 제22조에서 정한 의무를 위반한 경우 회사는 사안의 중요성과 다른 회원, 제3자, 회사가 입은 손해 등을 종합적으로 고려하여 회원에게 다음과 같은 제재를 할 수 있습니다.

   1. 서면경고 : 회사는 회원에게 의무위반의 내용, 위반 시기 등을 기재하여 서면으로 경고할 수 있습니다.

   2. 이용의 제한 : 회사는 회원의 의무위반의 정도 등 제반 사항을 고려하여 회사가 정한 기간 동안 해당 회원의 회사 홈페이지 또는 서비스 페이지 접속 등 일체의 서비스 이용을 제한할 수 있습니다.

   3. 영구 정지 : 회사는 회원의 계정을 영구적으로 정지할 수 있습니다.

## 제5장 손해배상 및 면책

### 제24조 (회사의 손해배상)

1. 회사는 자신에게 책임 있는 사유로 회원이 서비스의 이용과 관련하여 입은 손해를 배상할 책임이 있습니다.
2. 회원은 회사에 대한 손해배상 청구 시 청구 사유, 청구 금액 및 피해 산정의 근거 등을 명시한 서류를 제출하여야 하고, 회사는 배상 금액에서 회원의 이용요금을 제할 수 있습니다.
3. 본 조에 따른 회사의 손해배상책임은 관련 법령상 허용되는 범위 내에서 회사가 회원으로부터 지급받은 이용요금 총액을 한도로 제한됩니다.
4. 회사는 본 조에서 정한 사유를 비롯하여 회원과의 사이에서 서비스 계약을 체결하기 전 또는 체결한 서비스 계약의 이행과 관련하여 회원에게 어떠한 손해가 발생하더라도 회사의 고의 또는 중과실에 의한 손해를 제외하고는 책임을 부담하지 아니합니다.

### 제25조 (회원의 손해배상)

1. 회원은 다음 각 호의 어느 하나에 해당하는 사유로 분쟁이 발생하는 경우 회사, 계열사, 각각에 해당하는 임직원, 대리인, 협력사 및 라이선스 사용허가권자를 면책시키고 방어하며, 이들이 피해를 입지 않도록 모든 노력을 다하여야 합니다.
   1. 회원이 본 약관 또는 관련 법령에서 정하는 사항을 위반하거나 침해한 경우
   2. 회사가 약관 위반으로 의심되는 것을 조사하거나 약관 위반이 발생한 것으로 판단하여 조치를 취하는 경우
2. 회원은 자신에게 책임 있는 사유로 회사가 입은 손해를 배상할 책임이 있습니다.

### 제26조 (면책)

1. 회사는 다음 각 호의 경우에는 면책됩니다.
   1. 전시, 사변, 천재지변, 국가비상사태, 해결이 곤란한 기술적 결함 기타 불가항력적 사유로 서비스를 제공할 수 없는 경우
   2. 회원의 귀책사유로 인한 서비스의 중지, 이용 장애 및 서비스 이용계약이 해지된 경우
   3. 기간통신사업자가 전기통신서비스를 중지하거나 정상적으로 제공하지 아니한 경우
   4. 사전에 공지된 서비스용 설비의 보수, 교체, 정기점검, 공사 등 부득이한 사유로 서비스가 중지되거나 장애가 발생한 경우
   5. 회원의 컴퓨터 환경으로 인하여 발생하는 제반 문제 또는 회사의 고의 또는 중대한 과실이 없는 네트워크 환경으로 인하여 발생하는 문제로 인한 경우
   6. 서비스 관련 협력사의 설비 장애 등 협력사 관련 사유로 서비스 제공이 중지되거나 장애가 발생한 경우
   7. 회원 상호간 또는 회원과 제3자간에 서비스를 매개로 분쟁이 발생한 경우
   8. 회사가 제공하는 무료서비스와 관련하여 회사의 고의 또는 중대한 과실이 없는 경우
   9. 회사가 아닌 다른 사업자가 제공하는 서비스와 관련하여 회사의 고의 또는 중대한 과실이 없는 경우
   10. 서비스가 정상적으로 제공되었음에도 불구하고 회원이 주관적으로 기대하는 이익, 결과를 얻지 못하거나 상실한 경우 또는 회원의 취사선택으로 발생한 손해의 경우
   11. 회원의 컴퓨터 오류에 의한 손해가 발생한 경우 또는 신상정보 및 이메일 주소 등을 기재하지 아니하거나 부정확하게 기재하여 손해가 발생한 경우
   12. 관련 법령, 정부 정책 등에 따라 서비스를 제공할 수 없는 경우
   13. 회원 또는 제3자가 서비스 내 또는 회사 홈페이지 상에 게시 또는 전송한 정보, 자료, 사실의 신뢰도, 정확성 등의 내용에 대해서 회사의 고의 또는 중대한 과실이 없는 경우
   14. 회원이 데이터를 백업 또는 별도 저장하지 않은 채 클라우드 서비스 상에 업로드한 데이터가 회사에게 고의 또는 중과실 없는 사유로 멸실, 훼손, 손상이 이루어짐으로써 회원에게 손해가 발생한 경우
2. 회원은 자기의 권한 및 책임으로 회사 홈페이지 또는 서비스 페이지에 정보 및 의견을 게시하며 회사는 서비스 과정에서 회원이나 제3자에 의해 표시된 정보 및 의견의 사실 여부를 검증하거나 이를 승인하지 않습니다. 회사는 회원 또는 기타 유관기관이 서비스에 게재한 정보 및 의견의 진실성, 정확성, 신뢰도를 보장하지 않습니다. 따라서 회사는 회원이 위 정보 및 의견을 신뢰함으로 인하여 입게 된 모든 종류의 손실이나 손해에 대하여 책임을 부담하지 않습니다.
3. 회원의 불법적인 행위 또는 본 약관에 위반되는 행위로 인하여 회사에 손해가 발생하거나 수사기관, 행정기관으로부터 형사처벌 또는 제재를 받은 경우 회원은 회원의 비용(손해배상금, 소송비용, 변호사 비용 등을 포함하되 이에 한정하지 아니함)으로 회사를 면책하여야 합니다.

## 제6장 기타

### 제27조 (준거법 및 재판관할)

1. 본 약관 및 이용계약은 회원의 소재지와 무관하게 대한민국 법률의 적용을 받습니다.
2. 이용계약의 체결 또는 서비스의 제공과 관련하여 회사와 회원 사이에 분쟁이 발생한 경우, 회사와 회원은 발생한 분쟁을 원만하게 해결하기 위하여 필요한 모든 노력을 하여야 합니다. 발생한 분쟁에 대하여 소송이 제기될 경우에는 회사의 소재지를 관할하는 법원을 독점적 관할 법원으로 합니다.
3. 제1항에도 불구하고, 제2항에서 정한 관할 법원의 판결 및 판시 사항은 회사 또는 회원 소재지의 어느 법원에서나 집행이 가능합니다.

### 제28조 (분리 규정)

본 약관의 어느 조항이 법원 또는 관할 재판소에 의해 무효 또는 집행이 불가능하다고 판단되더라도, 그를 제외한 나머지 조항들의 집행 가능성은 이에 영향을 받지 않고 여전히 유효하며 강제력을 갖습니다.

### 제29조 (권리의 불포기)

회원의 약관 위반과 관련하여 회사가 권리의 실행이나 조치를 취하지 않았다고 하더라도, 이후 결과적으로 또는 유사하게 발생하는 행위에 대하여 회사가 약관의 권리 및 해당 권리의 실행을 포기하는 것으로 간주되지는 않습니다.

## 부칙

본 약관은 2019년 8월 15일에 작성되었으며, 2019년 8월 16일부터 적용됩니다.